"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatJSON = void 0;
const getEnv = (function () {
    let env;
    return () => {
        if (env)
            return env;
        if (typeof process !== 'undefined' && typeof process.version !== 'undefined') {
            return (env = `Node.js ${process.version}`);
        }
        if (typeof window !== 'undefined' && typeof window.navigator !== 'undefined') {
            return (env = window.navigator.userAgent);
        }
        return '';
    };
})();
function base64(str) {
    if (typeof btoa !== 'undefined')
        return btoa(str);
    if (typeof Buffer !== 'undefined')
        return Buffer.from(str).toString('base64');
    return str;
}
function rollup(error) {
    const stackLine = error.stack && error.stack.split('\n')[1];
    return base64(`${error.name}:${stackLine}`).replace(/=/g, '');
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function formatJSON(error, metadata = {}) {
    return Object.assign({}, metadata, {
        created_at: new Date().toISOString(),
        rollup: rollup(error),
        class: error.name,
        message: error.message,
        backtrace: error.stack || '',
        js_environment: getEnv()
    });
}
exports.formatJSON = formatJSON;
//# sourceMappingURL=json.js.map